;**********************************
; taylor_3.ncl
;**********************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"   
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"   
load "./taylor_diagram.ncl"
;**********************************
begin
;**********************************
; Assume the following have already been computed:
;   _ratio are the ratio:  Case_Variance/Reference_Variance
;   _cc    are the cross correlation coef of Case to Reference
;**********************************

; Cases [Model]
  case      = (/ "Anal 00Z", "Prev 24Z" , "Prev 48Z", "Prev 72Z" /) 
  nCase     = dimsizes(case )                 ; # of Cases [Cases]

; variables compared
   var       = (/ "Hs" /) 
  nVar      = dimsizes(var)                   ; # of Variables

; Case : "Anal 00Z"                        
  CA_ratio   = (/0.887/)
  CA_cc      = (/0.88/)

; Case:  "Prev 24Z" 
  CB_ratio   = (/0.889/)
  CB_cc      = (/0.87/)

; Case : "Prev 48Z"
  CC_ratio   = (/1.000/)
  CC_cc      = (/0.83/)

; Case:  "Prev 72Z"
  CD_ratio   = (/0.94/)
  CD_cc      = (/0.83/)


; arrays to be passed to taylor plot 
  ratio      = new ((/nCase, nVar/),typeof(CA_cc) )  
  cc         = new ((/nCase, nVar/),typeof(CA_cc) ) 

  ratio(0,:) = CA_ratio 
  ratio(1,:) = CB_ratio
  ratio(2,:) = CC_ratio
  ratio(3,:) = CD_ratio

  cc(0,:)    = CA_cc 
  cc(1,:)    = CB_cc
  cc(2,:)    = CC_cc
  cc(3,:)    = CD_cc

;**********************************
; create plot
;**********************************

  res   = True                           ; default taylor diagram
        
  res@Markers      = (/16, 16, 16, 16/)               ; make all solid fill
  res@Colors       = (/"red", "blue" , "green", "yellow"/)          
; res@varLabels    = var
  res@caseLabels   = case
  res@tiMainString  = "SC Buoy vs. WWATCH"           ; title
  res@stnRad        = (/ 0.5, 1.5 /)     ; additional standard radii
  res@ccRays        = (/ 0.6, 0.9 /)     ; correllation rays
  res@centerDiffRMS = False               ; RMS 'circles'
 
  wks   = gsn_open_wks("ps","taylor") 
  plot  = taylor_diagram(wks,ratio,cc,res)

  frame(wks)

end 

